==> plantuml-libs-7.1.0.tgz: package/distribution/fontawesome-6/Solid/HouseMedicalCircleXmark.md <==
# HouseMedicalCircleXmark


```text
fontawesome-6/Solid/HouseMedicalCircleXmark
```

```text
include('fontawesome-6/Solid/HouseMedicalCircleXmark')
```



| Illustration | HouseMedicalCircleXmark |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/HouseMedicalCircleXmark.png) | ![illustration for HouseMedicalCircleXmark](../../fontawesome-6/Solid/HouseMedicalCircleXmark.Local.png) |




## HouseMedicalCircleXmark

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleXmark
include('fontawesome-6/Solid/HouseMedicalCircleXmark')

' renders the element
HouseMedicalCircleXmark('HouseMedicalCircleXmark', 'House Medical Circle Xmark', 'an optional tech label')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleXmark
include('fontawesome-6/Solid/HouseMedicalCircleXmark')

' renders the element
HouseMedicalCircleXmark('HouseMedicalCircleXmark', 'House Medical Circle Xmark', 'an optional tech label')
@enduml
```

==> plantuml-libs-9.1.0.tgz: package/distribution/fontawesome-6/Solid/HouseMedicalCircleXmark.md <==
# HouseMedicalCircleXmark


```text
fontawesome-6/Solid/HouseMedicalCircleXmark
```

```text
include('fontawesome-6/Solid/HouseMedicalCircleXmark')
```



| Illustration | HouseMedicalCircleXmark |
| :---: | :---: |
| ![illustration for Illustration](../../fontawesome-6/Solid/HouseMedicalCircleXmark.png) | ![illustration for HouseMedicalCircleXmark](../../fontawesome-6/Solid/HouseMedicalCircleXmark.Local.png) |




## HouseMedicalCircleXmark

### Load remotely
```plantuml
@startuml
' configures the library
!global $LIB_BASE_LOCATION="https://raw.githubusercontent.com/tmorin/plantuml-libs/master/distribution"

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleXmark
include('fontawesome-6/Solid/HouseMedicalCircleXmark')

' renders the element
HouseMedicalCircleXmark('HouseMedicalCircleXmark', 'House Medical Circle Xmark', 'an optional tech label', 'an optional description')
@enduml
```

### Load locally
```plantuml
@startuml
' configures the library
!global $INCLUSION_MODE="local"
!global $LIB_BASE_LOCATION="../.."

' loads the library's bootstrap
!include $LIB_BASE_LOCATION/bootstrap.puml

' loads the package bootstrap
include('fontawesome-6/bootstrap')

' loads the Item which embeds the element HouseMedicalCircleXmark
include('fontawesome-6/Solid/HouseMedicalCircleXmark')

' renders the element
HouseMedicalCircleXmark('HouseMedicalCircleXmark', 'House Medical Circle Xmark', 'an optional tech label', 'an optional description')
@enduml
```
